# duckql-django 🐥

backboneQL bindings into [Django](https://www.djangoproject.com/) ORM and permissions system. This package suppose
to provide:

- Database introspection
- Ability to grant permissions to models and their properties
- Custom back-end query validation

## Resources

- [How Django Uses Metaclasses For Data Modelling](https://medium.com/swlh/how-django-use-data-descriptors-metaclasses-for-data-modelling-14b307280fce)
- [Advanced Python through Django: metaclasses](https://reinout.vanrees.org/weblog/2013/05/16/advanced-python-metaclasses.html)

---
Made with ☕️ and ❤️ by Jakub Dubec & [BACKBONE s.r.o.](https://www.backbone.sk/en/)
